@@ -2,7 +2,6 @@ context("betta")
 library(breakaway)
 
 test_that("betta isn't stupid", {
-  skip_on_cran()
   n <- 25
 
   bb <- betta(c(rep(7, n), rep(8, n)),
@@ -41,10 +40,8 @@ test_that("betta isn't stupid", {
                    ses = c(100, 200, 150, 180),
                    Cont_var = c(100, 150, 100, 50),
                    groups = c("a", "a", "a", "b"))
-  set.seed(0)
   b_formula <- betta_random(ses = ses,
                             formula = chats ~ Cont_var | groups, data = df)
-  set.seed(0)
   b_inputs <- betta_random(df$chats, df$ses,
                            X = cbind(Int = 1, df$Cont_var),
                            groups = df$groups)
@@ -70,10 +67,18 @@ test_that("betta isn't stupid", {
                  formula = pooleen ~ brybry | sarsh, data = df_uncouth),
     "list")
   expect_is(
-    betta_random(ses = dayved,
+    betta_random(ses = "dayved",
                  formula = pooleen ~ brybry | sarsh, data = df_uncouth),
     "list")
 
+  expect_error(
+    betta_random(ses = "dayved",
+                 formula = pooleen ~ brybry + sarsh, data = df_uncouth),
+    "Make sure that your formula includes `|` to specify a random effect if you'd like
+          to use `betta_random`. Otherwise, you can use `betta`."
+    
+  )
+  
   # issue 118
   df_issue118 <- df_uncouth
   df_issue118$dayved[1] <- 0
@@ -82,22 +87,30 @@ test_that("betta isn't stupid", {
   df_issue118_v2$dayved[1] <- NA
 
   expect_warning(
-    betta(ses = dayved,
+    betta(ses = "dayved",
           formula = pooleen ~ brybry, data = df_issue118),
     "At least one of your standard errors is 0 or NA. Any observation with
             a standard error of 0 or NA has been dropped from the analysis."
   )
 
   expect_equal(
-    betta(ses = dayved,
-          formula = pooleen ~ brybry, data = df_issue118)$table,
-    betta(ses = dayved,
-          formula = pooleen ~ brybry, data = df_issue118_v2)$table
+    # suppressing warnings here because they are the same warnings as in the test
+    # directly above and we want to test if two output tables are the same when a 
+    # standard error is 0 versus when a standard error is NA
+    suppressWarnings({
+      betta(ses = dayved,
+          formula = pooleen ~ brybry, data = df_issue118)$table}),
+    suppressWarnings({
+      betta(ses = dayved,
+          formula = pooleen ~ brybry, data = df_issue118_v2)$table})
   )
 
+  df_issue118_v3 <- df_issue118_v2
+  df_issue118_v3$dayved[1] <- 100
+  
   expect_error(
     betta(ses = dayved,
-          formula = pooleen ~ nutmeg, data = df_issue118_v2),
+          formula = pooleen ~ nutmeg, data = df_issue118_v3),
     "Your design matrix is not full rank. We recommend that you
          examine your design matrix for linear dependency and remove
          redundant columns."
@@ -115,7 +128,6 @@ test_that("betta isn't stupid", {
 })
 
 test_that("betta_lincom works with betta and betta_random", {
-  skip_on_cran()
   n <- 25
 
   bb <- betta(c(rep(7, n), rep(8, n)),
@@ -144,8 +156,6 @@ test_that("betta_lincom works with betta and betta_random", {
                    Cont_var = c(100, 150, 100, 50),
                    groups = c("a", "a", "a", "b"))
 
-  set.seed(0)
-
   b_formula <- betta_random(ses = ses,
                             formula = chats ~ Cont_var | groups, data = df)
 
@@ -153,63 +163,19 @@ test_that("betta_lincom works with betta and betta_random", {
 
   expect_is(b_lincom, "data.frame")
 
-  # expect_equal(as.numeric(b_lincom[,1]), 3000.301,
-  #              tolerance = 1e-4)
+  expect_equal(as.numeric(b_lincom[,1]), 3000.301,
+               tolerance = 1e-4)
 
-  # expect_equal(as.numeric(as.numeric(b_lincom[,2])), 918.2737)
+  expect_equal(as.numeric(as.numeric(b_lincom[,2])), 918.2737)
 
-  # expect_equal(as.numeric(as.numeric(b_lincom[,3])),  1200.518,
-  #              tolerance = 1e-5)
-  #
-  # expect_equal(as.numeric(b_lincom[,4]),  4800.084,
-  #              tolerance = 1e-5)
-  #
-  # expect_equal(as.numeric(b_lincom[,5]),  0.0005428401,
-  #              tolerance = 1e-5)
+  expect_equal(as.numeric(as.numeric(b_lincom[,3])),  1200.518,
+               tolerance = 1e-5)
+
+  expect_equal(as.numeric(b_lincom[,4]),  4800.084,
+               tolerance = 1e-5)
+
+  expect_equal(as.numeric(b_lincom[,5]),  0.0005428401,
+               tolerance = 1e-5)
 
 
 })
-
-test_that("betta_random works",{
-  skip_on_cran()
-  df <- data.frame(chats = c(2000, 3000, 4000, 3000,5000,4000),
-                   ses = c(100, 200, 150, 180,250,130),
-                   Cont_var = c(100, 150, 100, 50,150,100),
-                   groups = c("a", "a", "a", "b","b","b"))
-
-  df <- df[1:4,]
-
-  set.seed(0)
-
-  br_fitted <- betta_random(ses = ses,
-                            formula = chats ~ Cont_var | groups, data = df)
-
-  expect_equal(as.matrix(br_fitted$cov), rbind(c(1444378.73, -13624.3193),
-                                    c(-13624.3193,150.0946)) %>%
-                 (function(x){ colnames(x) <- c("(Intercept)","Cont_var")
-                 rownames(x) <- c("(Intercept)","Cont_var")
-                 return(x)}),
-               tol = .01)
-
-  expect_equal(as.matrix(br_fitted$table[,1]),
-               matrix(c(2998.97964029,
-                        -0.01697904 ), ncol = 1) %>%
-                 (function(x){
-                   rownames(x) <- c("(Intercept)",
-                                    "Cont_var")
-                   return(x)}),
-               tol = .01
-  )
-
-  expect_equal(as.matrix(br_fitted$table[,2]),
-               matrix(c(455.717045,
-                        4.645551 ), ncol = 1) %>%
-                 (function(x){
-                   rownames(x) <- c("(Intercept)",
-                                    "Cont_var")
-                   return(x)}),
-               tol = .01
-  )
-
-})
-
